@@ -1,4 +1,9 @@
 from .PyReplayBuffer import (ReplayBuffer,PrioritizedReplayBuffer,
                              SelectiveReplayBuffer)
 from .PyReplayBuffer import create_buffer
-from .util import create_env_dict, create_before_add_func
+
+try:
+    from .util import create_env_dict, create_before_add_func
+except ImportError:
+    pass
+
